=========
harvester
=========

*********************************
An easy-to-use Web Scraping tool.
*********************************

Harvester is a library written in plain python. Its goal is to provide a non-dependent library for easy web scraping.

************
Installation
************

Installing from pip::

    pip install harvester

Installing from source::

    pip install git+https://github.com/blazaid/harvester

Requirements
============

There are no mandatory requirements. However to use option A, is necessary the installation of library `chardet <https://pypi.python.org/pypi/chardet>`_ is mandatory. If it is not
installed, the option will be ignored leaving a trace.

*************
Documentation
*************

We're exporting the documentation to "readthedocs". Until then, the source code is a very good place (and the only one) to get the documentation. We'll upload the docs as soon as
we can.

*******
Authors
*******

`harvester` was written by `Blazaid <alberto.da@gmail.com>`_ with help from `Davyria <https://github.com/davyria>`_.

Thanks
======

To you.


Warning
=======

It has been developed with only python 3.X in mind, so it won't probably work on lower versions (i.e. no python 2.X support).

Second warning
==============

English included in both this document and the code can be devastating for the brain of an average human being. Even so we, the poor developers, are working hard to write as
correctly as possible and learn along the way. The documentation will be updated as we improve our language proficency as well as we receive critical / suggestions for this.